akhdefo_functions.Mosaic — Akhdefo software documentation

# akhdefo_functions.Mosaic

akhdefo_functions.Mosaic(Path_to_WorkingDir='', output_MosaicDir='', img_mode=0)

  This program mosiacs raster images in geotif format as well grab dates the satellite image taken for further processing. The current version only supports Planet Labs SurfaceReflectance products.

  ## Parameters

  Path_to_WorkingDir : str

  output_MosaicDir : str

  img_modeint

    if img_mode=0 the the programs mosaics only the raster images. if img_mode=1 the program mosiacs only mask rasters

  ## Returns

  Mosaiced raster images